@@ -86,7 +86,22 @@ static int umssync_create (
 	struct umsdos_info info;
 	umsdos_parse (name,strlen(name),&info);
 	int ret = -1;
-	if (info.msdos_reject){
+	if (strchr(name,' ')!=NULL){
+		/* #Specification: umssync / special system file
+			One glitch in the msdos fs (the linux driver) is that it
+			shows system and hidden file. This is useless. OS/2 have
+			some special hidden file for extended attribute. These
+			file are hidden and have a space in the name. This
+			cause some problem to the msdos fs (they appear but
+			can't be access !). umssync try to promote these
+			file by renaming them. bad!!!
+
+			To avoid this, umssync will silently ignore those file.
+			Hopefully the msdos fs will be fixed to hide to special file
+			anyway.
+		*/
+		ret = 0;
+	}else if (info.msdos_reject){
 		/* #Specification: umssync / mangled name
 			If a DOS file is missing from the EMD, it is added. If
 			the file has an extension with the first character
@@ -117,7 +132,7 @@ static int umssync_create (
 
 			Now, suppose that dir.{__ does not exist in the EMD. dir.{_1
 			do exist in DOS. If we try to create it in Umsdos, this
-			will create a mangled name. Mangling in based on the
+			will create a mangled name. Mangling is based on the
 			entry offset in the EMD.
 		*/
 		// Don't care about hidden hard link
@@ -125,10 +140,11 @@ static int umssync_create (
 		// make sure all hidden link are referenced.
 		if (strncmp(name,"__link",6)!=0){
 			char newname[13];
-			strcpy (newname,name);
+			umsdos_manglename (&info);
+			strcpy (newname,info.fake.fname);
 			char *pt = strchr(newname,'.');
 			if (pt == NULL){
-				sprintf (newname,"%s.$%02d",name,largest);
+				sprintf (newname,"%s.$%02d",info.fake.fname,largest);
 			}else{
 				sprintf (pt+1,"$%02d",largest);
 			}
@@ -145,12 +161,12 @@ static int umssync_create (
 			ret = 0;
 		}
 	}else{
-		struct stat stat;
-		ret = ioc.dosstat (name,stat);
+		struct stat fstat;
+		ret = ioc.dosstat (name,fstat);
 		if (ret != -1){
 			mode_t mode;
 			const char *msgtype;
-			if (S_ISDIR(stat.st_mode)){
+			if (S_ISDIR(fstat.st_mode)){
 				mode = opt.dir_mode|S_IFDIR;
 				msgtype = "dir";
 			}else{
@@ -158,8 +174,8 @@ static int umssync_create (
 				msgtype = "file";
 			}
 			if (opt.verbose) printf ("Creating %s %s\n",msgtype,fpath);
-			ret = ioc.create (name,mode,stat.st_mtime,stat.st_mtime
-				,stat.st_mtime,opt.uid,opt.gid,0);
+			ret = ioc.create (name,mode,fstat.st_mtime,fstat.st_mtime
+				,fstat.st_mtime,opt.uid,opt.gid,0);
 		}
 	}
 	return ret;
@@ -228,11 +244,11 @@ static int umssync_addsdir(
 	int &nbsub)
 {
 	int ret = -1;
-	struct stat stat;
-	if (ioc.dosstat(dos_name,stat)==-1){
+	struct stat fstat;
+	if (ioc.dosstat(dos_name,fstat)==-1){
 		fprintf (stderr,"dosstat failed for entry %s\n",ums_name);
 		ret = 0;
-	}else if (S_ISDIR(stat.st_mode)){
+	}else if (S_ISDIR(fstat.st_mode)){
 		if (nbsub < maxsub){
 			ret = 0;
 			UMS_DIRINFO *ptsub = tbsub + nbsub++;
